@@ -1746,7 +1746,7 @@ static void set_special_folder(GtkCMCTree *ctree, FolderItem *item,
 
 		node = gtk_cmctree_find_by_row_data(ctree, root, item);
 		if (!node)
-			g_warning("%s not found.\n", item->path);
+			g_warning("%s not found.", item->path);
 		else {
 			parent = GTK_CMCTREE_ROW(node)->parent;
 			if (*prev && parent == GTK_CMCTREE_ROW(*prev)->parent)
@@ -1995,6 +1995,9 @@ static gboolean folderview_button_released(GtkWidget *ctree, GdkEventButton *eve
 static gboolean folderview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 				       FolderView *folderview)
 {
+	GtkCMCTreeNode *node;
+	FolderItem *item;
+
 	if (!event) return FALSE;
 
 	if (quicksearch_has_focus(folderview->summaryview->quicksearch))
@@ -2007,8 +2010,12 @@ static gboolean folderview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 	case GDK_KEY_KP_Enter:
 #endif
 		if (folderview->selected) {
-			folderview_select_node(folderview,
-					       folderview->selected);
+			if (!GTK_CMCTREE_ROW(folderview->selected)->expanded)
+				gtk_cmctree_expand(GTK_CMCTREE(folderview->ctree),
+						folderview->selected);
+			else
+				folderview_select_node(folderview,
+						       folderview->selected);
 		}
 		break;
 #ifdef GENERIC_UMPC
@@ -2032,6 +2039,39 @@ static gboolean folderview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 						       folderview->selected);
 		}
 		break;
+	case GDK_KEY_Left:
+		if (folderview->selected) {
+			if (GTK_CMCTREE_ROW(folderview->selected)->expanded) {
+				gtk_cmctree_collapse(GTK_CMCTREE(folderview->ctree),
+						folderview->selected);
+			} else {
+				if ((item = gtk_cmctree_node_get_row_data(GTK_CMCTREE(folderview->ctree),
+						folderview->selected))) {
+					if ((node = gtk_cmctree_find_by_row_data(GTK_CMCTREE(folderview->ctree),
+							NULL, folder_item_parent(item)))) {
+						gtk_cmctree_select(GTK_CMCTREE(folderview->ctree), node);
+						if (!gtk_cmctree_node_is_visible(GTK_CMCTREE(folderview->ctree), node))
+							gtk_cmctree_node_moveto(GTK_CMCTREE(folderview->ctree),
+									node, -1, 0, 0);
+					}
+				}
+			}
+		}
+		break;
+	case GDK_KEY_Home:
+	case GDK_KEY_End:
+		if (event->keyval == GDK_KEY_Home)
+			node = gtk_cmctree_node_nth(GTK_CMCTREE(folderview->ctree), 0);
+		else
+			node = gtk_cmctree_last(GTK_CMCTREE(folderview->ctree),
+					gtk_cmctree_node_nth(GTK_CMCTREE(folderview->ctree), 0));
+
+		gtk_cmctree_select(GTK_CMCTREE(folderview->ctree), node);
+
+		if (!gtk_cmctree_node_is_visible(GTK_CMCTREE(folderview->ctree), node))
+			gtk_cmctree_node_moveto(GTK_CMCTREE(folderview->ctree),
+					node, -1, 0, 0);
+		break;
 	default:
 		break;
 	}
@@ -2760,7 +2800,7 @@ static void folderview_drag_data_get(GtkWidget        *widget,
 					       source, strlen(source));
 		}
 	} else {
-		g_warning("unknown info %d\n", info);
+		g_warning("unknown info %d", info);
 	}
 }
 
