@@ -1859,14 +1859,14 @@ static void register_templates_page(void)
 
 static GSList *prefs_pages = NULL;
 
-static void prefs_folder_item_address_completion_start(GtkWindow * window)
+static void prefs_folder_item_address_completion_start(PrefsWindow *window)
 {
-	address_completion_start(GTK_WIDGET(window));
+	address_completion_start(window->window);
 }
 
-static void prefs_folder_item_address_completion_end(GtkWindow * window)
+static void prefs_folder_item_address_completion_end(PrefsWindow *window)
 {
-	address_completion_end(GTK_WIDGET(window));
+	address_completion_end(window->window);
 }
 
 void prefs_folder_item_open(FolderItem *item)
@@ -1897,6 +1897,7 @@ void prefs_folder_item_open(FolderItem *item)
 	prefswindow_open(title, pages, item,
 			&prefs_common.folderitemwin_width, &prefs_common.folderitemwin_height,
 			prefs_folder_item_address_completion_start,
+			NULL,
 			prefs_folder_item_address_completion_end);
 
 	g_slist_free(pages);
